@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: dwmdns.cc 10719 2020-05-06 19:43:39Z dwm $
+// @(#) $Id: dwmdns.cc 11271 2020-11-23 01:14:19Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018
 //  All rights reserved.
@@ -48,7 +48,7 @@
 #include "DwmDnsResolver.hh"
 #include "DwmDnsUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.2/apps/dwmdns/dwmdns.cc 10719 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.5/apps/dwmdns/dwmdns.cc 11271 $");
 
 using namespace std;
 using namespace Dwm;
@@ -180,7 +180,7 @@ int main(int argc, char *argv[])
   
   string  requestedTypes = optArgs.Get<string>('t');
   if (requestedTypes.empty()) {
-    requestedTypes = "a,aaaa";
+    requestedTypes = "aaaa,a";
   }
   vector<string>  rectypes;
   Dwm::StringUtils::StringToVector(requestedTypes, ',', rectypes);
