@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.2/classes/src/DwmDnsMessageQuestion.cc 10133 $
-// @(#) $Id: DwmDnsMessageQuestion.cc 10133 2018-01-27 17:41:32Z dwm $
+// @(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.5/classes/src/DwmDnsMessageQuestion.cc 11433 $
+// @(#) $Id: DwmDnsMessageQuestion.cc 11433 2020-12-13 06:35:55Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2000, 2016, 2018
 //  All rights reserved.
@@ -50,7 +50,7 @@ extern "C" {
 #include "DwmDnsLabelSequence.hh"
 #include "DwmDnsMessageQuestion.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.2/classes/src/DwmDnsMessageQuestion.cc 10133 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/DwmDns/tags/DwmDns-0.2.5/classes/src/DwmDnsMessageQuestion.cc 11433 $");
 
 using namespace std;
 
@@ -58,6 +58,42 @@ namespace Dwm {
 
   namespace Dns {
 
+    const map<uint16_t,string>  MessageQuestion::_qtypeNames = {
+      { k_typeA,          "A"          },
+      { k_typeNS,         "NS"         },
+      { k_typeCNAME,      "CNAME"      },
+      { k_typeSOA,        "SOA"        },
+      { k_typeMB,         "MB"         },
+      { k_typeMG,         "MG"         },
+      { k_typeMR,         "MR"         },
+      { k_typePTR,        "PTR"        },
+      { k_typeHINFO,      "HINFO"      },
+      { k_typeMINFO,      "MINFO"      },
+      { k_typeMX,         "MX"         },
+      { k_typeTXT,        "TXT"        },
+      { k_typeRP,         "RP"         },
+      { k_typeKEY,        "KEY"        },
+      { k_typeAAAA,       "AAAA"       },
+      { k_typeLOC,        "LOC"        },
+      { k_typeSRV,        "SRV"        },
+      { k_typeCERT,       "CERT"       },
+      { k_typeDS,         "DS"         },
+      { k_typeSSHFP,      "SSHFP"      },
+      { k_typeRRSIG,      "RRSIG"      },
+      { k_typeNSEC,       "NSEC"       },
+      { k_typeDNSKEY,     "DNSKEY"     },
+      { k_typeDHCID,      "DHCID"      },
+      { k_typeNSEC3,      "NSEC3"      },
+      { k_typeNSEC3PARAM, "NSEC3PARAM" },
+      { k_typeTLSA,       "TLSA"       },
+      { k_typeSMIMEA,     "SMIMEA"     },
+      { k_typeCDS,        "CDS"        },
+      { k_typeCDNSKEY,    "CDNSKEY"    },
+      { k_typeOPENPGPKEY, "OPENPGPKEY" },
+      { k_typeURI,        "URI"        },
+      { k_typeCAA,        "CAA"        }
+    };
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
@@ -116,7 +152,20 @@ namespace Dwm {
       _qtype = qtype;
       return _qtype;
     }
-    
+
+    //------------------------------------------------------------------------
+    //!  
+    //------------------------------------------------------------------------
+    std::string MessageQuestion::QTypeString() const
+    {
+      std::string  rc;
+      auto  it = _qtypeNames.find(_qtype);
+      if (it != _qtypeNames.end()) {
+        rc = it->second;
+      }
+      return rc;
+    }
+
     //------------------------------------------------------------------------
     //!  
     //------------------------------------------------------------------------
